@@ -6,18 +6,18 @@
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-use strict;          ## no critic (UselessNoCritic RequireExplicitPackage)
-use warnings;        ## no critic (UselessNoCritic RequireExplicitPackage)
-use Modern::Perl;    ## no critic (UselessNoCritic RequireExplicitPackage)
+use utf8;
+use Modern::Perl;    ## no critic (UselessNoCritic,RequireExplicitPackage)
 
 package SVN::Simple::Hook;
 
 BEGIN {
-    $SVN::Simple::Hook::VERSION = '0.110071';
+    $SVN::Simple::Hook::VERSION = '0.200';
 }
 
 # ABSTRACT: Simple Moose-based framework for Subversion hooks
 
+use strict;
 use English '-no_match_vars';
 use Moose::Role;
 use MooseX::Has::Sugar;
@@ -37,7 +37,7 @@ has repos_path => (
     documentation => 'repository path',
 );
 
-has _repos => (
+has repository => (
     ro, required, lazy,
     isa      => '_p_svn_repos_t',
     init_arg => undef,
@@ -45,17 +45,28 @@ has _repos => (
     default => sub { SVN::Repos::open( shift->repos_path->stringify() ) },
 );
 
+has author => ( ro, required, lazy_build, isa => Str, init_arg => undef );
+
+has root => ( ro, required, lazy_build,
+    isa      => '_p_svn_fs_root_t',
+    init_arg => undef,
+);
+
 1;
 
 =pod
 
+=for :stopwords Mark Gardner GSI Commerce
+
+=encoding utf8
+
 =head1 NAME
 
 SVN::Simple::Hook - Simple Moose-based framework for Subversion hooks
 
 =head1 VERSION
 
-version 0.110071
+version 0.200
 
 =head1 SYNOPSIS
 
@@ -72,6 +83,21 @@ is extremely unstable at the moment.  You have been warned!
 
 L<Directory|Path::Class::Dir> containing the Subversion repository.
 
+=head2 repository
+
+Subversion L<repository object|SVN::Repos/_p_svn_repos_t>.  Opened on first
+call to the accessor.
+
+=head2 author
+
+Author of the current revision or transaction.  Role consumers must provide a
+C<_build_author> method to set a default value.
+
+=head2 root
+
+L<Subversion root object|SVN::Fs/_p_svn_fs_root_t> from the repository.  Role
+consumers must provide a C<_build_root> method to set a default value.
+
 =for test_synopsis 1;
 
 =for test_synopsis __END__
@@ -81,6 +107,15 @@ L<Directory|Path::Class::Dir> containing the Subversion repository.
 See L<SVN::Simple::Hook::PreCommit|SVN::Simple::Hook::PreCommit/SYNOPSIS> for
 an example.  This role exists solely to be composed into other roles.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+http://github.com/mjgardner/SVN-Simple-Hook/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Mark Gardner <mjgardner@cpan.org>
