@@ -6,18 +6,18 @@
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-use strict;          ## no critic (UselessNoCritic RequireExplicitPackage)
-use warnings;        ## no critic (UselessNoCritic RequireExplicitPackage)
-use Modern::Perl;    ## no critic (UselessNoCritic RequireExplicitPackage)
+use utf8;
+use Modern::Perl;    ## no critic (UselessNoCritic,RequireExplicitPackage)
 
 package SVN::Simple::Hook::PreCommit;
 
 BEGIN {
-    $SVN::Simple::Hook::PreCommit::VERSION = '0.110071';
+    $SVN::Simple::Hook::PreCommit::VERSION = '0.200';
 }
 
 # ABSTRACT: Role for Subversion pre-commit hooks
 
+use strict;
 use English '-no_match_vars';
 use Moose::Role;
 use MooseX::Has::Sugar;
@@ -36,24 +36,34 @@ has txn_name => (
     documentation => 'commit transaction name',
 );
 
-has txn => (
+has transaction => (
     ro, required, lazy,
     isa      => '_p_svn_fs_txn_t',
     init_arg => undef,
-    default  => sub { $ARG[0]->_repos->fs->open_txn( $ARG[0]->txn_name ) },
+    default => sub { $ARG[0]->repository->fs->open_txn( $ARG[0]->txn_name ) },
 );
 
+{
+    ## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
+    sub _build_author { return shift->transaction->prop('svn:author') }
+    sub _build_root   { return shift->transaction->root() }
+}
+
 1;
 
 =pod
 
+=for :stopwords Mark Gardner GSI Commerce
+
+=encoding utf8
+
 =head1 NAME
 
 SVN::Simple::Hook::PreCommit - Role for Subversion pre-commit hooks
 
 =head1 VERSION
 
-version 0.110071
+version 0.200
 
 =head1 SYNOPSIS
 
@@ -65,32 +75,47 @@ version 0.110071
     use Moose;
     extends 'MooseX::App::Cmd::Command';
     with 'SVN::Simple::Hook::PreCommit';
-    
+
     sub execute {
         my ( $self, $opt, $args ) = @_;
         my $txn = $self->txn();
-        
-        warn $txn->prop('svn:author'), ' changed ',
-            scalar keys %{ $txn->root->paths_changed() }, " paths\n";
-        
+
+        warn $self->author, ' changed ',
+            scalar keys %{ $self->root->paths_changed() }, " paths\n";
+
         return;
     }
-    
-    1;
 
 =head1 DESCRIPTION
 
+This L<Moose::Role|Moose::Role> gives you access to the current Subversion
+transaction for use in a pre-commit hook.  It's designed for use with
+L<MooseX::App::Cmd::Command|MooseX::App::Cmd::Command> classes, so consult
+the main L<MooseX::App::Cmd documentation|MooseX::App::Command> for details
+on how to extend it to create your scripts.
+
 =head1 ATTRIBUTES
 
 =head2 txn_name
 
 Full name of the transaction to check in the repository.
 
-=for test_synopsis 1;
+=head2 transaction
 
-=for test_synopsis __END__
+The current L<Subversion transaction|SVN::Fs/_p_svn_fs_txn_t>, automatically
+populated at object creation time when the L<txn_name|/txn_name> is set.
 
-In your repository's F<hooks/pre-commit> file:
+=head2 author
+
+The author of the current transaction as required by all
+L<SVN::Simple::Hook|SVN::Simple::Hook> consumers.
+
+=head2 root
+
+The L<Subversion root|SVN::Fs/_p_svn_fs_root_t> node as required by all
+L<SVN::Simple::Hook|SVN::Simple::Hook> consumers.
+
+=head1 Example F<hooks/pre-commit> hook script
 
     #!/bin/sh
 
@@ -100,6 +125,15 @@ In your repository's F<hooks/pre-commit> file:
     perl -MMyHook::Cmd -e 'MyHook::Cmd->run()' pre_commit -r "$REPOS" -t "$TXN" || exit 1
     exit 0
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+http://github.com/mjgardner/SVN-Simple-Hook/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Mark Gardner <mjgardner@cpan.org>
